import { Node } from 'unist';
import unified from 'unified';
import { NoteLinkDefinition, Resource, ResourceLink, ResourceParser } from './model/note';
import { URI } from './model/uri';
import { FoamWorkspace } from './model/workspace';
import { IDataStore, IMatcher } from './services/datastore';
import { IDisposable } from './common/lifecycle';
import { ResourceProvider } from './model/provider';
export interface ParserPlugin {
    name?: string;
    visit?: (node: Node, note: Resource, noteSource: string) => void;
    onDidInitializeParser?: (parser: unified.Processor) => void;
    onWillParseMarkdown?: (markdown: string) => string;
    onWillVisitTree?: (tree: Node, note: Resource) => void;
    onDidVisitTree?: (tree: Node, note: Resource) => void;
    onDidFindProperties?: (properties: any, note: Resource, node: Node) => void;
}
export declare class MarkdownResourceProvider implements ResourceProvider {
    private readonly matcher;
    private readonly watcherInit?;
    private readonly parser;
    private readonly dataStore;
    private disposables;
    constructor(matcher: IMatcher, watcherInit?: ((triggers: {
        onDidChange: (uri: URI) => void;
        onDidCreate: (uri: URI) => void;
        onDidDelete: (uri: URI) => void;
    }) => IDisposable[]) | undefined, parser?: ResourceParser, dataStore?: IDataStore);
    init(workspace: FoamWorkspace): Promise<void>;
    supports(uri: URI): boolean;
    read(uri: URI): Promise<string | null>;
    readAsMarkdown(uri: URI): Promise<string | null>;
    fetch(uri: URI): Promise<Resource | null>;
    resolveLink(workspace: FoamWorkspace, resource: Resource, link: ResourceLink): URI;
    dispose(): void;
}
export declare function createMarkdownParser(extraPlugins: ParserPlugin[]): ResourceParser;
export declare function stringifyMarkdownLinkReferenceDefinition(definition: NoteLinkDefinition): string;
export declare function createMarkdownReferences(workspace: FoamWorkspace, noteUri: URI, includeExtension: boolean): NoteLinkDefinition[];
