import { Resource, ResourceLink } from './note';
import { URI } from './uri';
import { FoamWorkspace } from './workspace';
import { IDisposable } from '../common/lifecycle';
export declare type Connection = {
    source: URI;
    target: URI;
    link: ResourceLink;
};
export declare class FoamGraph implements IDisposable {
    private readonly workspace;
    /**
     * Placehoders by key / slug / value
     */
    readonly placeholders: Map<string, URI>;
    /**
     * Maps the connections starting from a URI
     */
    readonly links: Map<string, Connection[]>;
    /**
     * Maps the connections arriving to a URI
     */
    readonly backlinks: Map<string, Connection[]>;
    /**
     * List of disposables to destroy with the workspace
     */
    private disposables;
    constructor(workspace: FoamWorkspace);
    contains(uri: URI): boolean;
    getAllNodes(): URI[];
    getAllConnections(): Connection[];
    getConnections(uri: URI): Connection[];
    getLinks(uri: URI): Connection[];
    getBacklinks(uri: URI): Connection[];
    /**
     * Computes all the links in the workspace, connecting notes and
     * creating placeholders.
     *
     * @param workspace the target workspace
     * @param keepMonitoring whether to recompute the links when the workspace changes
     * @returns the FoamGraph
     */
    static fromWorkspace(workspace: FoamWorkspace, keepMonitoring?: boolean): FoamGraph;
    private updateLinksRelatedToAddedResource;
    private updateLinksForResource;
    private updateLinksRelatedToDeletedResource;
    private connect;
    /**
     * Removes a connection, or all connections, between the source and
     * target resources
     *
     * @param workspace the Foam workspace
     * @param source the source resource
     * @param target the target resource
     * @param link the link reference, or `true` to remove all links
     * @returns the updated Foam workspace
     */
    private disconnect;
    resolveResource(resource: Resource): this;
    dispose(): void;
}
