import { URI } from './uri';
import { Position } from './position';
import { Range } from './range';
export interface NoteSource {
    text: string;
    contentStart: Position;
    end: Position;
    eol: string;
}
export interface WikiLink {
    type: 'wikilink';
    target: string;
    label: string;
    rawText: string;
    range: Range;
}
export interface DirectLink {
    type: 'link';
    label: string;
    target: string;
    range: Range;
}
export declare type ResourceLink = WikiLink | DirectLink;
export interface NoteLinkDefinition {
    label: string;
    url: string;
    title?: string;
    range?: Range;
}
export interface Tag {
    label: string;
    range: Range;
}
export interface Section {
    label: string;
    range: Range;
}
export interface Resource {
    uri: URI;
    type: string;
    title: string;
    properties: any;
    sections: Section[];
    tags: Tag[];
    links: ResourceLink[];
    definitions: NoteLinkDefinition[];
    source: NoteSource;
}
export interface ResourceParser {
    parse: (uri: URI, text: string) => Resource;
}
export declare abstract class Resource {
    static sortByTitle(a: Resource, b: Resource): number;
    static isResource(thing: any): thing is Resource;
    static findSection(resource: Resource, label: string): Section | null;
}
