import { Resource, ResourceLink } from './note';
import { URI } from './uri';
import { ResourceProvider } from './provider';
import { IDisposable } from '../common/lifecycle';
export declare class FoamWorkspace implements IDisposable {
    private onDidAddEmitter;
    private onDidUpdateEmitter;
    private onDidDeleteEmitter;
    onDidAdd: import("../common/event").Event<Resource>;
    onDidUpdate: import("../common/event").Event<{
        old: Resource;
        new: Resource;
    }>;
    onDidDelete: import("../common/event").Event<Resource>;
    private providers;
    /**
     * Resources by path
     */
    private resources;
    registerProvider(provider: ResourceProvider): Promise<void>;
    set(resource: Resource): this;
    delete(uri: URI): Resource | null;
    exists(uri: URI): boolean;
    list(): Resource[];
    get(uri: URI): Resource;
    listByIdentifier(identifier: string): Resource[];
    /**
     * Returns the minimal identifier for the given resource
     *
     * @param forResource the resource to compute the identifier for
     */
    getIdentifier(forResource: URI): string;
    find(reference: URI | string, baseUri?: URI): Resource | null;
    resolveLink(resource: Resource, link: ResourceLink): URI;
    read(uri: URI): Promise<string | null>;
    readAsMarkdown(uri: URI): Promise<string | null>;
    dispose(): void;
    static isIdentifier(path: string): boolean;
    /**
     * Returns the minimal identifier for the given string amongst others
     *
     * @param forPath the value to compute the identifier for
     * @param amongst the set of strings within which to find the identifier
     */
    static getShortestIdentifier(forPath: string, amongst: string[]): string;
}
