import { URI } from '../model/uri';
export interface IMatcher {
    /**
     * Filters the given list of URIs, keepin only the ones that
     * are matched by this Matcher
     *
     * @param files the URIs to check
     */
    match(files: URI[]): URI[];
    /**
     * Returns whether this URI is matched by this Matcher
     *
     * @param uri the URI to check
     */
    isMatch(uri: URI): boolean;
    /**
     * The include globs
     */
    include: string[];
    /**
     * The exclude lobs
     */
    exclude: string[];
}
/**
 * The matcher requires the path to be in unix format, so if we are in windows
 * we convert the fs path on the way in and out
 */
export declare const toMatcherPathFormat: (uri: URI) => string;
export declare const toFsPath: (path: string) => string;
export declare class Matcher implements IMatcher {
    readonly folders: string[];
    readonly include: string[];
    readonly exclude: string[];
    constructor(baseFolders: URI[], include?: string[], exclude?: string[]);
    match(files: URI[]): URI[];
    isMatch(uri: URI): boolean;
}
/**
 * Represents a source of files and content
 */
export interface IDataStore {
    /**
     * List the files matching the given glob from the
     * store
     */
    list: (glob: string, ignoreGlob?: string | string[]) => Promise<URI[]>;
    /**
     * Read the content of the file from the store
     *
     * Returns `null` in case of errors while reading
     */
    read: (uri: URI) => Promise<string | null>;
}
/**
 * File system based data store
 */
export declare class FileDataStore implements IDataStore {
    list(glob: string, ignoreGlob?: string | string[]): Promise<URI[]>;
    read(uri: URI): Promise<string | null>;
}
export declare const folderPlusGlob: (folder: string) => (glob: string) => string;
