"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRandomURI = exports.randomString = exports.wait = exports.createTestNote = exports.createTestWorkspace = exports.strToUri = exports.TEST_DATA_DIR = void 0;
/*
 * This file should not depend on VS Code as it's used for unit tests
 */
const log_1 = require("../core/utils/log");
const range_1 = require("../core/model/range");
const uri_1 = require("../core/model/uri");
const workspace_1 = require("../core/model/workspace");
const datastore_1 = require("../core/services/datastore");
const markdown_provider_1 = require("../core/markdown-provider");
log_1.Logger.setLevel('error');
exports.TEST_DATA_DIR = uri_1.URI.file(__dirname).joinPath('..', '..', 'test-data');
const position = range_1.Range.create(0, 0, 0, 100);
const documentStart = position.start;
const documentEnd = position.end;
const eol = '\n';
/**
 * Turns a string into a URI
 * The goal of this function is to make sure we are consistent in the
 * way we generate URIs (and therefore IDs) across the tests
 */
exports.strToUri = uri_1.URI.file;
exports.createTestWorkspace = () => {
    const workspace = new workspace_1.FoamWorkspace();
    const matcher = new datastore_1.Matcher([uri_1.URI.file('/')], ['**/*']);
    const provider = new markdown_provider_1.MarkdownResourceProvider(matcher, undefined, undefined, {
        read: _ => Promise.resolve(''),
        list: _ => Promise.resolve([]),
    });
    workspace.registerProvider(provider);
    return workspace;
};
exports.createTestNote = (params) => {
    var _a, _b, _c, _d, _e, _f, _g;
    const root = (_a = params.root) !== null && _a !== void 0 ? _a : uri_1.URI.file('/');
    return {
        uri: root.resolve(params.uri),
        type: 'note',
        properties: {},
        title: (_b = params.title) !== null && _b !== void 0 ? _b : exports.strToUri(params.uri).getBasename(),
        definitions: (_c = params.definitions) !== null && _c !== void 0 ? _c : [],
        sections: ((_d = params.sections) === null || _d === void 0 ? void 0 : _d.map(label => ({
            label,
            range: range_1.Range.create(0, 0, 1, 0),
        }))) || [],
        tags: (_f = (_e = params.tags) === null || _e === void 0 ? void 0 : _e.map(t => ({
            label: t,
            range: range_1.Range.create(0, 0, 0, 0),
        }))) !== null && _f !== void 0 ? _f : [],
        links: params.links
            ? params.links.map((link, index) => {
                const range = range_1.Range.create(position.start.line + index, position.start.character, position.start.line + index, position.end.character);
                return 'slug' in link
                    ? {
                        type: 'wikilink',
                        target: link.slug,
                        label: link.slug,
                        range: range,
                        rawText: 'link text',
                    }
                    : {
                        type: 'link',
                        target: link.to,
                        label: 'link text',
                        range: range,
                    };
            })
            : [],
        source: {
            eol: eol,
            end: documentEnd,
            contentStart: documentStart,
            text: (_g = params.text) !== null && _g !== void 0 ? _g : '',
        },
    };
};
exports.wait = (ms) => new Promise(resolve => setTimeout(resolve, ms));
const chars = 'abcdefghijklmnopqrstuvwyxzABCDEFGHIJKLMNOPQRSTUVWYXZ1234567890';
exports.randomString = (len = 5) => new Array(len)
    .fill('')
    .map(() => chars.charAt(Math.floor(Math.random() * chars.length)))
    .join('');
exports.getRandomURI = () => uri_1.URI.file('/random-uri-root/' + exports.randomString() + '.md');
